Django GeoIP
============

.. image:: https://secure.travis-ci.org/futurecolors/django-geoip.png?branch=dev
    :target: https://travis-ci.org/futurecolors/django-geoip

.. image:: https://coveralls.io/repos/futurecolors/django-geoip/badge.png?branch=dev
    :target: https://coveralls.io/r/futurecolors/django-geoip/

App to figure out where your visitors are from by their IP address.

Detects country, region and city, querying the database with geodata.
Optional high-level API provides user location in request object.

Requires Django 1.4+, supports python 2.6, 2.7, 3.4, 3.5.

Docs: http://django-geoip.readthedocs.org/
